@@ -57,6 +57,14 @@ SEG_DUP_INTERVALS_HT_PATH = join(
 )
 CLINVAR_HT_PATH = join(REF_BUCKET, 'gnomad/clinvar/clinvar_20190923.ht')
 
+GNOMAD_HT_PATH = (
+    'gs://gcp-public-data--gnomad/release/3.1/ht/genomes/gnomad.genomes.v3.1.sites.ht/'
+)
+GNOMAD_HGDP_1KG_MT_PATH = (
+    'gs://gcp-public-data--gnomad/release/3.1/mt/genomes/'
+    'gnomad.genomes.v3.1.hgdp_1kg_subset_dense.mt'
+)
+
 NUMBER_OF_HAPLOTYPE_CALLER_INTERVALS = 50
 NUMBER_OF_GENOMICS_DB_INTERVALS = 50
 
@@ -229,7 +237,6 @@ def get_mt(
     add_meta: bool = False,
     release_only: bool = False,
     passing_sites_only: bool = False,
-    biallelic_snps_only: bool = False,
 ) -> hl.MatrixTable:
     """
     Wrapper function to get data with desired filtering and metadata annotations
@@ -247,7 +254,6 @@ def get_mt(
         release (can only be used if metadata is present)
     :param passing_sites_only: whether to filter the MT to only variants with
         nothing in the filter field (e.g. passing soft filters)
-    :param biallelic_snps_only: remove all multiallelic calls and all indels
     :return: MatrixTable with chosen annotations and filters
     """
     mt = hl.read_matrix_table(mt_path)
@@ -284,11 +290,6 @@ def get_mt(
         # Will use GT instead of LGT
         mt = hl.experimental.sparse_split_multi(mt, filter_changed_loci=True)
 
-    if biallelic_snps_only:
-        mt = mt.filter_rows(
-            (hl.len(mt.alleles) == 2) & hl.is_snp(mt.alleles[0], mt.alleles[1])
-        )
-
     return mt
 
 
@@ -332,9 +333,9 @@ def get_filter_cutoffs(
 
     if path.startswith('gs://'):
         contents = subprocess.check_output(['gsutil', 'cat', path])
-        filter_cutoffs_d = yaml.load(contents)
+        filter_cutoffs_d = yaml.safe_load(contents)
     else:
         with open(path) as f:
-            filter_cutoffs_d = yaml.load(f)
+            filter_cutoffs_d = yaml.safe_load(f)
 
     return filter_cutoffs_d
